



if not exist %PREFIX%\\Library\\bin\\LimeSuiteGUI.exe exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
LimeUtil --info
IF %ERRORLEVEL% NEQ 0 exit /B 1
SoapySDRUtil --info
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
